@@ -8,7 +8,7 @@
 #include "pimcommonakonadi_debug.h"
 #include "util/mailutil.h"
 
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -37,10 +37,7 @@ ManageServerSideSubscriptionJob::ManageServerSideSubscriptionJob(QObject *parent
 {
 }
 
-ManageServerSideSubscriptionJob::~ManageServerSideSubscriptionJob()
-{
-    delete d;
-}
+ManageServerSideSubscriptionJob::~ManageServerSideSubscriptionJob() = default;
 
 void ManageServerSideSubscriptionJob::start()
 {
@@ -79,7 +76,6 @@ void ManageServerSideSubscriptionJob::slotConfigureSubscriptionFinished(QDBusPen
         qCDebug(PIMCOMMONAKONADI_LOG) << "ManageServerSideSubscriptionJob return an invalid reply";
     }
     watcher->deleteLater();
-    watcher = nullptr;
     deleteLater();
 }
 
